selexe manual — selexe v0.1.0 documentation

### Navigation

- index
- next |
- previous |
- selexe v0.1.0 documentation »

# selexe manual

This still needs to be written.

#### Previous topic

Installation

#### Next topic

This is the MIT license

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- selexe v0.1.0 documentation »

© Copyright 2012, Ralph Heinkel. Created using Sphinx 0.6.3.